searchData={"items":[{"type":"module","title":"IssApi","doc":"The `IssApi` is a simple library that functions as a wrapper for the Open Notify\nAPI.\n\nThe wrapper currently supports one of the two endpoints, which is the current\nlocation of the International Space Station. It fetches the data returned from\nthe API, parses the JSON to a map and then transforms it to a struct before passing\nit to the caller.\n\nThe API has two dependencies that is uses for providing all the functionality to the\ncaller:\n\n* HTTPoison: This is used to make GET requests to the Open Notify API\n* Jason: This is used to parse the JSON returned to a map\n\nCredits for the API go to it's creators and full details on it can be found on \n[Open Notify](http://open-notify.org).","ref":"IssApi.html"},{"type":"function","title":"IssApi.location/0","doc":"This will return the current location of the International Space Station.\n\nThe function will return a tuple. The first value is an atom and will be either \n`:ok` or `:error`. The second value will be a map with the following structure: \n\n```\n@type iss_location :: %{timestamp: unix_epoch(), position: {latitude(), longitude()}}\n```\n\nWhen an `:error` is returned, it will have another tuple as the second element. The tuple\nwill contain an error code and the value that caused the error.\n\nThe response has two fields and three values in total. The first field\nis the `timestamp` field. This will return the time in UNIX format. Meaning \nit will return the amount of seconds that have passed since 1 January 1970.\nThe second field is the `position` field. This is a tuple containing to floats,\nthe `latitude` and the `longitude`.","ref":"IssApi.html#location/0"},{"type":"function","title":"Examples - IssApi.location/0","doc":"IssApi.location()\n    {:ok, %{timestamp: 1699027915, position: {35.9648, -143.0953}}}","ref":"IssApi.html#location/0-examples"},{"type":"type","title":"IssApi.error/0","doc":"","ref":"IssApi.html#t:error/0"},{"type":"type","title":"IssApi.iss_location/0","doc":"","ref":"IssApi.html#t:iss_location/0"},{"type":"type","title":"IssApi.latitude/0","doc":"","ref":"IssApi.html#t:latitude/0"},{"type":"type","title":"IssApi.longitude/0","doc":"","ref":"IssApi.html#t:longitude/0"},{"type":"type","title":"IssApi.unix_epoch/0","doc":"","ref":"IssApi.html#t:unix_epoch/0"},{"type":"extras","title":"IssApi","doc":"# IssApi\n\n![Elixir CI](https://github.com/MikkelvtK/iss_api/actions/workflows/elixir.yml/badge.svg) [![Coverage Status](https://coveralls.io/repos/github/MikkelvtK/iss_api/badge.svg?branch=main)](https://coveralls.io/github/MikkelvtK/iss_api?branch=main) ![Hex.pm](https://img.shields.io/hexpm/v/iss_api)","ref":"readme.html"},{"type":"extras","title":"Description - IssApi","doc":"IssApi is a wrapper written in Elixir for [Open Notify](http://open-notify.org). It provides a way to tap in to\nsome of NASA's data via an API interface. It currently supports two different endpoints:\n\n* [Current location of the ISS](http://open-notify.org/Open-Notify-API/ISS-Location-Now/)\n* [Number of people in space](http://open-notify.org/Open-Notify-API/People-In-Space/)\n\nAs of now the wrapper only supports the current location of the ISS, but will add the second endpoint \nat some point.\n\n#","ref":"readme.html#description"},{"type":"extras","title":"Current Location of the ISS - IssApi","doc":"The current location of the ISS is provided by the Open notify API in the following format:\n\n```JSON\n{\n  \"message\": \"success\", \n  \"timestamp\": UNIX_TIME_STAMP, \n  \"iss_position\": {\n    \"latitude\": CURRENT_LATITUDE, \n    \"longitude\": CURRENT_LONGITUDE\n  }\n}\n```\n\nThe `UNIX_TIME_STAMP` is of type integer and will be parsed directly by the wrapper. The `CURRENT_LATITUDE` \nand `CURRENT_LONGITUDE` are of type float, but are presented as strings in the API. The `IssApi` wrapper will\nparse these values to float directly so they can be directly used in the code without having to do anything\nextra.\n\nAn example of what that would look like:\n\n```elixir\niex> IssApi.location()\n{:ok, %{position: {35.9648, -143.0953}, timestamp: 1699027915}}\n```\n\nAs shown above, the function will return a tuple where the first element will be either `:ok` or `:error` and the second\nelement will be the response. In case of `:ok`, the response will be a map with two keys. The first one is `position`, \nwhich will have a value that is a tuple. The first value of the tuple is the latitude and the second element is\nthe longitude. The second key is the `timestamp`. When an `:error` is returned, it will always return a tuple where \nthe second element is another tuple with the error code and the value that caused the error.","ref":"readme.html#current-location-of-the-iss"},{"type":"extras","title":"Installation - IssApi","doc":"To use the library add the `IssApi` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:iss_api, \"~> 0.1.2\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown"}